"""IMS MCP Server package."""

try:
    from importlib.metadata import version

    __version__ = version("ims-mcp")
except Exception:
    __version__ = "unknown"

__author__ = "Igor Solomatov"

# Default PostHog Project API Key (injected during CI/CD build from GitHub secret)
DEFAULT_POSTHOG_API_KEY = "__POSTHOG_API_KEY_PLACEHOLDER__"

from ims_mcp.server import mcp

__all__ = ["mcp", "__version__", "DEFAULT_POSTHOG_API_KEY"]
